@@ -2,6 +2,7 @@
 """Transforming arrays of Mantarray data throughout the analysis pipeline."""
 from typing import Any
 from typing import Dict
+from typing import Iterable
 from typing import List
 from typing import Optional
 from typing import Tuple
@@ -12,6 +13,7 @@ import attr
 from nptyping import NDArray
 import numpy as np
 
+from .constants import ALL_METRICS
 from .exceptions import DataAlreadyLoadedInPipelineError
 from .peak_detection import data_metrics
 from .peak_detection import peak_detector
@@ -25,9 +27,7 @@ from .transforms import create_filter
 from .transforms import noise_cancellation
 
 
-if (
-    6 < 9
-):  # pragma: no cover # protect this from zimports deleting the pylint disable statement
+if 6 < 9:  # pragma: no cover # protect this from zimports deleting the pylint disable statement
     from .compression_cy import (  # pylint: disable=import-error # Eli (8/18/20) unsure why pylint is unable to recognize cython import...
         compress_filtered_gmr,
     )
@@ -58,7 +58,7 @@ class Pipeline:
         self._displacement: NDArray[(2, Any), np.float32]
         self._force: NDArray[(2, Any), np.float32]
         self._peak_detection_results: Tuple[List[int], List[int]]
-        self._magnetic_data_metrics: Tuple[  # pylint:disable=duplicate-code # Anna (1/7/21): long type definition causing failture
+        self._magnetic_data_metrics: Tuple[  # pylint:disable=duplicate-code # Anna (1/7/21): long type definition causing failure
             Dict[
                 int,
                 Dict[
@@ -77,7 +77,7 @@ class Pipeline:
                 ],
             ],
         ]
-        self._displacement_data_metrics: Tuple[  # pylint:disable=duplicate-code # Anna (1/7/21): long type definition causing failture
+        self._displacement_data_metrics: Tuple[  # pylint:disable=duplicate-code # Anna (1/7/21): long type definition causing failure
             Dict[
                 int,
                 Dict[
@@ -96,7 +96,7 @@ class Pipeline:
                 ],
             ],
         ]
-        self._force_data_metrics: Tuple[  # pylint:disable=duplicate-code # Anna (1/7/21): long type definition causing failture
+        self._force_data_metrics: Tuple[  # pylint:disable=duplicate-code # Anna (1/7/21): long type definition causing failure
             Dict[
                 int,
                 Dict[
@@ -188,9 +188,7 @@ class Pipeline:
             return self._fully_calibrated_magnetic_data
         except AttributeError:
             pass
-        self._fully_calibrated_magnetic_data = apply_empty_plate_calibration(
-            self.get_noise_cancelled_gmr()
-        )
+        self._fully_calibrated_magnetic_data = apply_empty_plate_calibration(self.get_noise_cancelled_gmr())
         return self._fully_calibrated_magnetic_data
 
     def get_noise_filtered_gmr(self) -> NDArray[(2, Any), int]:
@@ -225,7 +223,8 @@ class Pipeline:
 
     def get_magnetic_data_metrics(
         self,
-    ) -> Tuple[  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failture
+        metrics_to_create: Iterable[UUID] = ALL_METRICS,
+    ) -> Tuple[  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failure
         Dict[
             int,
             Dict[
@@ -238,9 +237,7 @@ class Pipeline:
         ],
         Dict[
             UUID,
-            Union[
-                Dict[str, Union[float, int]], Dict[int, Dict[str, Union[float, int]]]
-            ],
+            Union[Dict[str, Union[float, int]], Dict[int, Dict[str, Union[float, int]]]],
         ],
     ]:
         """Calculate data metrics on noise filtered magnetic data."""
@@ -249,13 +246,16 @@ class Pipeline:
         except AttributeError:
             pass
         self._magnetic_data_metrics = data_metrics(
-            self.get_peak_detection_results(), self.get_noise_filtered_magnetic_data()
+            self.get_peak_detection_results(),
+            self.get_noise_filtered_magnetic_data(),
+            metrics_to_create=metrics_to_create,
         )
         return self._magnetic_data_metrics
 
     def get_displacement_data_metrics(
         self,
-    ) -> Tuple[  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failture
+        metrics_to_create: Iterable[UUID] = ALL_METRICS,
+    ) -> Tuple[  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failure
         Dict[
             int,
             Dict[
@@ -268,9 +268,7 @@ class Pipeline:
         ],
         Dict[
             UUID,
-            Union[
-                Dict[str, Union[float, int]], Dict[int, Dict[str, Union[float, int]]]
-            ],
+            Union[Dict[str, Union[float, int]], Dict[int, Dict[str, Union[float, int]]]],
         ],
     ]:
         """Calculate data metrics on displacement data."""
@@ -279,13 +277,17 @@ class Pipeline:
         except AttributeError:
             pass
         self._displacement_data_metrics = data_metrics(
-            self.get_peak_detection_results(), self.get_displacement(), rounded=False
+            self.get_peak_detection_results(),
+            self.get_displacement(),
+            rounded=False,
+            metrics_to_create=metrics_to_create,
         )
         return self._displacement_data_metrics
 
     def get_force_data_metrics(
         self,
-    ) -> Tuple[  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failture
+        metrics_to_create: Iterable[UUID] = ALL_METRICS,
+    ) -> Tuple[  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failure
         Dict[
             int,
             Dict[
@@ -298,9 +300,7 @@ class Pipeline:
         ],
         Dict[
             UUID,
-            Union[
-                Dict[str, Union[float, int]], Dict[int, Dict[str, Union[float, int]]]
-            ],
+            Union[Dict[str, Union[float, int]], Dict[int, Dict[str, Union[float, int]]]],
         ],
     ]:
         """Calculate data metrics on force data."""
@@ -309,7 +309,10 @@ class Pipeline:
         except AttributeError:
             pass
         self._force_data_metrics = data_metrics(
-            self.get_peak_detection_results(), self.get_force(), rounded=False
+            self.get_peak_detection_results(),
+            self.get_force(),
+            rounded=False,
+            metrics_to_create=metrics_to_create,
         )
         return self._force_data_metrics
 
@@ -321,9 +324,7 @@ class Pipeline:
             return self._compressed_magnetic_data
         except AttributeError:
             pass
-        self._compressed_magnetic_data = compress_filtered_gmr(
-            self.get_noise_filtered_magnetic_data()
-        )
+        self._compressed_magnetic_data = compress_filtered_gmr(self.get_noise_filtered_magnetic_data())
         return self._compressed_magnetic_data
 
     def get_compressed_voltage(self) -> NDArray[(2, Any), np.float32]:
@@ -339,9 +340,7 @@ class Pipeline:
             return self._compressed_displacement
         except AttributeError:
             pass
-        self._compressed_displacement = calculate_displacement_from_voltage(
-            self.get_compressed_voltage()
-        )
+        self._compressed_displacement = calculate_displacement_from_voltage(self.get_compressed_voltage())
         return self._compressed_displacement
 
     def get_compressed_force(self) -> NDArray[(2, Any), np.float32]:
@@ -349,9 +348,7 @@ class Pipeline:
             return self._compressed_force
         except AttributeError:
             pass
-        self._compressed_force = calculate_force_from_displacement(
-            self.get_compressed_displacement()
-        )
+        self._compressed_force = calculate_force_from_displacement(self.get_compressed_displacement())
         return self._compressed_force
 
     def get_voltage(self) -> NDArray[(2, Any), np.float32]:
@@ -419,7 +416,5 @@ class PipelineTemplate:  # pylint: disable=too-few-public-methods # This is a si
             return self._filter_coefficients
         except AttributeError:
             pass
-        self._filter_coefficients = create_filter(
-            self.noise_filter_uuid, self.tissue_sampling_period
-        )
+        self._filter_coefficients = create_filter(self.noise_filter_uuid, self.tissue_sampling_period)
         return self._filter_coefficients
